from django import template
from django.contrib.auth.models import AnonymousUser
from django.test import RequestFactory
from django.test.utils import override_settings
import mock

from test_app import views
from waffle.middleware import WaffleMiddleware
from waffle.tests.base import TestCase


def get():
    request = RequestFactory().get('/foo')
    request.user = AnonymousUser()
    return request


def process_request(request, view):
    response = view(request)
    return WaffleMiddleware().process_response(request, response)


class WaffleTemplateTests(TestCase):

    def test_django_tags(self):
        request = get()
        response = process_request(request, views.flag_in_django)
        self.assertContains(response, 'flag off')
        self.assertContains(response, 'switch off')
        self.assertContains(response, 'sample')
        self.assertContains(response, 'flag_var off')
        self.assertContains(response, 'switch_var off')
        self.assertContains(response, 'sample_var')
        self.assertContains(response, 'window.waffle =')

    def test_no_request_context(self):
        """Switches and Samples shouldn't require a request context."""
        request = get()
        content = process_request(request, views.no_request_context)
        assert 'switch off' in content
        assert 'sample' in content

    @override_settings(TEMPLATE_LOADERS=(
        'jingo.Loader',
        'django.template.loaders.filesystem.Loader',
        'django.template.loaders.app_directories.Loader',
    ))
    @mock.patch.object(template.loader, 'template_source_loaders', None)
    def test_jingo_tags(self):
        """
            We're manually changing default TEMPLATE_LOADERS to enable jingo

            template_source_loaders needs to be patched to None, otherwise
            TEMPLATE_LOADERS won't be overriden.
        """
        request = get()
        response = process_request(request, views.flag_in_jingo)
        self.assertContains(response, 'flag off')
        self.assertContains(response, 'switch off')
        self.assertContains(response, 'sample')
        self.assertContains(response, 'window.waffle =')



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations


class Migration(migrations.Migration):

    dependencies = [
        ('waffle', '0003_verifieduser'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='flag',
            name='sessions',
        ),
    ]



from __future__ import unicode_literals

from django.conf import settings


CACHE_PREFIX = getattr(settings, 'WAFFLE_CACHE_PREFIX', 'waffle:')
COOKIE_NAME = getattr(settings, 'WAFFLE_COOKIE', 'dwf_%s')
TEST_COOKIE_NAME = getattr(settings, 'WAFFLE_TESTING_COOKIE', 'dwft_%s')
FLAG_CACHE_KEY = getattr(settings, 'WAFFLE_FLAG_CACHE_KEY', 'flag:%s')
FLAGS_ALL_CACHE_KEY = getattr(settings, 'WAFFLE_FLAGS_ALL_CACHE_KEY', 'flags:all')
FLAG_USERS_CACHE_KEY = getattr(settings, 'WAFFLE_FLAG_USERS_CACHE_KEY', 'flag:%s:users')
FLAG_GROUPS_CACHE_KEY = getattr(settings, 'WAFFLE_FLAG_GROUPS_CACHE_KEY', 'flag:%s:groups')
SAMPLE_CACHE_KEY = getattr(settings, 'WAFFLE_SAMPLE_CACHE_KEY', 'sample:%s')
SAMPLES_ALL_CACHE_KEY = getattr(settings, 'WAFFLE_SAMPLES_ALL_CACHE_KEY', 'samples:all')
SWITCH_CACHE_KEY = getattr(settings, 'WAFFLE_SWITCH_CACHE_KEY', 'switch:%s')
SWITCHES_ALL_CACHE_KEY = getattr(settings, 'WAFFLE_SWITCHES_ALL_CACHE_KEY', 'switches:all')


SWITCH_DEFAULT = getattr(settings, 'WAFFLE_SWITCH_DEFAULT', False)
FLAG_DEFAULT = getattr(settings, 'WAFFLE_FLAG_DEFAULT', False)
SAMPLE_DEFAULT = getattr(settings, 'WAFFLE_SAMPLE_DEFAULT', False)

SECURE = getattr(settings, 'WAFFLE_SECURE', False)
MAX_AGE = getattr(settings, 'WAFFLE_MAX_AGE', 2592000)  # 1 month
OVERRIDE = getattr(settings, 'WAFFLE_OVERRIDE', False)
